/* event-test.c -- Test for event
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of EBCS.

EBCS is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

EBCS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with EBCS; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/*! @page lcd-test Test program for the LCD operations.

  This program tests the LCD operation by displaying patterns on
  the LCD panel.

  @htmlonly
  Source file: <a href="lcd-test_c-source.html">lcd-test.c</a>
  @endhtmlonly

 */

#include <sys/param.h>
#include <gel/timer.h>
#include <sys/sio.h>
#include <sys/locks.h>
#include <gel/event.h>
#include <test.h>
#include <stdio.h>
#include <benchs.h>
#include <time.h>

void event_benchs (void);

event event_queue[16];

void
event_benchs ()
{
  bench_t b;
  unsigned char stop;

  bench_init (&b);

  unlock ();
  stop = 1;
  bench_start (&b);
  event_loop (0x10000, &stop);
  bench_stop (&b);
  bench_report (&b, "event_loop (10,false) [%ld]", event_idle_counter);

  event_idle_counter = 0;
  stop = 0;
  bench_start (&b);
  event_loop (128 * 65536, &stop);
  bench_stop (&b);
  bench_report (&b, "event_loop (128 TOVF) [%ld]", event_idle_counter);
}

int
main ()
{
  int result;

  serial_init ();

  timer_initialize ();
  event_initialize (event_queue, 16);
  
  test_repeat = 100;
  test_depend ("serial:timer:benchs");
  test_start ("event-test");
  result = test_end ("event-test");
  if (result == 0)
    {
      event_benchs ();
    }
  return result;
}
