/* ltime-test.c -- Localtime test
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of EBCS.

EBCS is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

EBCS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with EBCS; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/*! @page lcd-test Test program for the LCD operations.

  This program tests the LCD operation by displaying patterns on
  the LCD panel.

  @htmlonly
  Source file: <a href="lcd-test_c-source.html">lcd-test.c</a>
  @endhtmlonly

 */

#include <sys/param.h>
#include <gel/timer.h>
#include <sys/sio.h>

#include <test.h>
#include <stdio.h>
#include <benchs.h>
#include <time.h>

void localtime_benchs (void);

void
localtime_benchs ()
{
  bench_t b;
  struct tm t;
  time_t n;
  
  bench_init (&b);

  n = 0xffffffff;
  bench_start (&b);
  localtime_r (&n, &t);
  bench_stop (&b);
  bench_report (&b, "localtime_r (%ld-%ld-%ld)",
		(long) (t.tm_year + 1900),
		(long) (t.tm_mon),
		(long) (t.tm_mday));

  n = 0x80000000;
  bench_start (&b);
  localtime_r (&n, &t);
  bench_stop (&b);
  bench_report (&b, "localtime_r (%ld-%ld-%ld)",
		(long) (t.tm_year + 1900),
		(long) (t.tm_mon),
		(long) (t.tm_mday));

  n = 0x40000000;
  bench_start (&b);
  localtime_r (&n, &t);
  bench_stop (&b);
  bench_report (&b, "localtime_r (%ld-%ld-%ld)",
		(long) (t.tm_year + 1900),
		(long) (t.tm_mon),
		(long) (t.tm_mday));

  n = 0x20000000;
  bench_start (&b);
  localtime_r (&n, &t);
  bench_stop (&b);
  bench_report (&b, "localtime_r (%ld-%ld-%ld)",
		(long) (t.tm_year + 1900),
		(long) (t.tm_mon),
		(long) (t.tm_mday));
}

int
main ()
{
  int result;
  unsigned long i;

  serial_init ();

  timer_initialize ();
  test_repeat = 100;
  test_depend ("serial:benchs");
  test_start ("localtime-test");
  for (i = 0; i < test_repeat; i++)
    {
    }
  result = test_end ("localtime-test");
  if (result == 0)
    {
      localtime_benchs ();
    }
  return result;
}
